@@ -18,12 +18,12 @@ async def get_all_trade_transforms():
 @router.put('/transform/trade')
 async def create_trade_transform(trade_transform: TradeTransform):
     trade_transform_repository = ItemHolder.get_entity(TradeTransformRepository)
-    trade_transform_repository.append(trade_transform)
+    trade_transform_repository.create(trade_transform)
     return trade_transform
 
 
 @router.delete('/transform/trade')
 async def delete_trade_transform(trade_transform: TradeTransform):
     trade_transform_repository = ItemHolder.get_entity(TradeTransformRepository)
-    trade_transform_repository.remove(trade_transform)
+    trade_transform_repository.delete(trade_transform)
     return trade_transform
